bread.contrib.activities.management package
===========================================

.. automodule:: bread.contrib.activities.management
   :members:
   :undoc-members:
   :show-inheritance:

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   bread.contrib.activities.management.commands
